"""This module contains the meta information of FsmDebugAction ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("FsmDebugAction", "fsmDebugAction", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "dn": MethodPropertyMeta("Dn", "dn", "ReferenceObject", "Version142b", "InputOutput", False),
    "in_directive": MethodPropertyMeta("InDirective", "inDirective", "Xs:string", "Version142b", "Input", False),
}

prop_map = {
    "cookie": "cookie",
    "dn": "dn",
    "inDirective": "in_directive",
}



"""This module contains the meta information of ConfigFindPackDependencies ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ConfigFindPackDependencies", "configFindPackDependencies", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "dn": MethodPropertyMeta("Dn", "dn", "ReferenceObject", "Version142b", "InputOutput", False),
    "in_chassis_pack_dns": MethodPropertyMeta("InChassisPackDns", "inChassisPackDns", "DnSet", "Version142b", "Input", True),
    "in_host_pack_dns": MethodPropertyMeta("InHostPackDns", "inHostPackDns", "DnSet", "Version142b", "Input", True),
    "out_config_set": MethodPropertyMeta("OutConfigSet", "outConfigSet", "ConfigSet", "Version142b", "Output", True),
}

prop_map = {
    "cookie": "cookie",
    "dn": "dn",
    "inChassisPackDns": "in_chassis_pack_dns",
    "inHostPackDns": "in_host_pack_dns",
    "outConfigSet": "out_config_set",
}



"""This module contains the general information for NetworkIfStats ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class NetworkIfStatsConsts:
    TYPE_BROADCAST = "broadcast"
    TYPE_GENERIC = "generic"
    TYPE_MULTICAST = "multicast"
    TYPE_TOTAL = "total"
    TYPE_UNICAST = "unicast"
    UNITS_OCTETS = "octets"
    UNITS_PACKETS = "packets"
    UNITS_RAW = "raw"


class NetworkIfStats(ManagedObject):
    """This is NetworkIfStats class."""

    consts = NetworkIfStatsConsts()
    naming_props = set(['type', 'units'])

    mo_meta = MoMeta("NetworkIfStats", "networkIfStats", "if-stat-[type]-[units]", VersionMeta.Version101e, "InputOutput", 0x7f, [], ["read-only"], ['adaptorHostEthIf', 'adaptorHostFcIf', 'adaptorHostIscsiIf', 'adaptorHostScsiIf', 'adaptorHostServiceEthIf', 'etherPIo', 'fcPIo'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "out": MoPropertyMeta("out", "out", "ulong", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rin": MoPropertyMeta("rin", "rin", "ulong", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x20, None, None, None, ["broadcast", "generic", "multicast", "total", "unicast"], []),
        "units": MoPropertyMeta("units", "units", "string", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x40, None, None, None, ["octets", "packets", "raw"], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "out": "out", 
        "rin": "rin", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "type": "type", 
        "units": "units", 
    }

    def __init__(self, parent_mo_or_dn, type, units, **kwargs):
        self._dirty_mask = 0
        self.type = type
        self.units = units
        self.child_action = None
        self.out = None
        self.rin = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "NetworkIfStats", parent_mo_or_dn, **kwargs)



"""This module contains the general information for EquipmentRaidDef ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class EquipmentRaidDefConsts:
    INT_ID_NONE = "none"
    LEVEL_ANY_CONFIGURATION = "any-configuration"
    LEVEL_BEST_EFFORT_MIRRORED = "best-effort-mirrored"
    LEVEL_BEST_EFFORT_MIRRORED_STRIPED = "best-effort-mirrored-striped"
    LEVEL_BEST_EFFORT_STRIPED = "best-effort-striped"
    LEVEL_BEST_EFFORT_STRIPED_DUAL_PARITY = "best-effort-striped-dual-parity"
    LEVEL_BEST_EFFORT_STRIPED_PARITY = "best-effort-striped-parity"
    LEVEL_DUAL_DISK = "dual-disk"
    LEVEL_NO_LOCAL_STORAGE = "no-local-storage"
    LEVEL_NO_RAID = "no-raid"
    LEVEL_RAID_MIRRORED = "raid-mirrored"
    LEVEL_RAID_MIRRORED_STRIPED = "raid-mirrored-striped"
    LEVEL_RAID_STRIPED = "raid-striped"
    LEVEL_RAID_STRIPED_DUAL_PARITY = "raid-striped-dual-parity"
    LEVEL_RAID_STRIPED_DUAL_PARITY_STRIPED = "raid-striped-dual-parity-striped"
    LEVEL_RAID_STRIPED_PARITY = "raid-striped-parity"
    LEVEL_RAID_STRIPED_PARITY_STRIPED = "raid-striped-parity-striped"
    LEVEL_SINGLE_DISK = "single-disk"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"


class EquipmentRaidDef(ManagedObject):
    """This is EquipmentRaidDef class."""

    consts = EquipmentRaidDefConsts()
    naming_props = set(['level'])

    mo_meta = MoMeta("EquipmentRaidDef", "equipmentRaidDef", "[level]", VersionMeta.Version141i, "InputOutput", 0x1ff, [], [""], ['equipmentLocalDiskControllerCapProvider'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version141i, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version141i, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]),
        "level": MoPropertyMeta("level", "level", "string", VersionMeta.Version141i, MoPropertyMeta.NAMING, 0x10, None, None, None, ["any-configuration", "best-effort-mirrored", "best-effort-mirrored-striped", "best-effort-striped", "best-effort-striped-dual-parity", "best-effort-striped-parity", "dual-disk", "no-local-storage", "no-raid", "raid-mirrored", "raid-mirrored-striped", "raid-striped", "raid-striped-dual-parity", "raid-striped-dual-parity-striped", "raid-striped-parity", "raid-striped-parity-striped", "single-disk"], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, ["local", "pending-policy", "policy"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, 0x80, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x100, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "intId": "int_id", 
        "level": "level", 
        "name": "name", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, level, **kwargs):
        self._dirty_mask = 0
        self.level = level
        self.child_action = None
        self.descr = None
        self.int_id = None
        self.name = None
        self.policy_level = None
        self.policy_owner = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "EquipmentRaidDef", parent_mo_or_dn, **kwargs)



"""This module contains the general information for AdaptorMenloMcpuStatsHist ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class AdaptorMenloMcpuStatsHistConsts:
    MOST_RECENT_FALSE = "false"
    MOST_RECENT_NO = "no"
    MOST_RECENT_TRUE = "true"
    MOST_RECENT_YES = "yes"
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class AdaptorMenloMcpuStatsHist(ManagedObject):
    """This is AdaptorMenloMcpuStatsHist class."""

    consts = AdaptorMenloMcpuStatsHistConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("AdaptorMenloMcpuStatsHist", "adaptorMenloMcpuStatsHist", "[id]", VersionMeta.Version111j, "OutputOnly", 0xf, [], ["read-only"], ['adaptorMenloMcpuStats'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111j, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "drop_acl": MoPropertyMeta("drop_acl", "dropAcl", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "drop_acl_delta": MoPropertyMeta("drop_acl_delta", "dropAclDelta", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "drop_acl_delta_avg": MoPropertyMeta("drop_acl_delta_avg", "dropAclDeltaAvg", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "drop_acl_delta_max": MoPropertyMeta("drop_acl_delta_max", "dropAclDeltaMax", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "drop_acl_delta_min": MoPropertyMeta("drop_acl_delta_min", "dropAclDeltaMin", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "drop_overrun": MoPropertyMeta("drop_overrun", "dropOverrun", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "drop_overrun_delta": MoPropertyMeta("drop_overrun_delta", "dropOverrunDelta", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "drop_overrun_delta_avg": MoPropertyMeta("drop_overrun_delta_avg", "dropOverrunDeltaAvg", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "drop_overrun_delta_max": MoPropertyMeta("drop_overrun_delta_max", "dropOverrunDeltaMax", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "drop_overrun_delta_min": MoPropertyMeta("drop_overrun_delta_min", "dropOverrunDeltaMin", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "drop_runt": MoPropertyMeta("drop_runt", "dropRunt", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "drop_runt_delta": MoPropertyMeta("drop_runt_delta", "dropRuntDelta", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "drop_runt_delta_avg": MoPropertyMeta("drop_runt_delta_avg", "dropRuntDeltaAvg", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "drop_runt_delta_max": MoPropertyMeta("drop_runt_delta_max", "dropRuntDeltaMax", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "drop_runt_delta_min": MoPropertyMeta("drop_runt_delta_min", "dropRuntDeltaMin", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "id": MoPropertyMeta("id", "id", "ulong", VersionMeta.Version111j, MoPropertyMeta.NAMING, None, None, None, None, [], []),
        "most_recent": MoPropertyMeta("most_recent", "mostRecent", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "truncate_overrun": MoPropertyMeta("truncate_overrun", "truncateOverrun", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "truncate_overrun_delta": MoPropertyMeta("truncate_overrun_delta", "truncateOverrunDelta", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "truncate_overrun_delta_avg": MoPropertyMeta("truncate_overrun_delta_avg", "truncateOverrunDeltaAvg", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "truncate_overrun_delta_max": MoPropertyMeta("truncate_overrun_delta_max", "truncateOverrunDeltaMax", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "truncate_overrun_delta_min": MoPropertyMeta("truncate_overrun_delta_min", "truncateOverrunDeltaMin", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "dropAcl": "drop_acl", 
        "dropAclDelta": "drop_acl_delta", 
        "dropAclDeltaAvg": "drop_acl_delta_avg", 
        "dropAclDeltaMax": "drop_acl_delta_max", 
        "dropAclDeltaMin": "drop_acl_delta_min", 
        "dropOverrun": "drop_overrun", 
        "dropOverrunDelta": "drop_overrun_delta", 
        "dropOverrunDeltaAvg": "drop_overrun_delta_avg", 
        "dropOverrunDeltaMax": "drop_overrun_delta_max", 
        "dropOverrunDeltaMin": "drop_overrun_delta_min", 
        "dropRunt": "drop_runt", 
        "dropRuntDelta": "drop_runt_delta", 
        "dropRuntDeltaAvg": "drop_runt_delta_avg", 
        "dropRuntDeltaMax": "drop_runt_delta_max", 
        "dropRuntDeltaMin": "drop_runt_delta_min", 
        "id": "id", 
        "mostRecent": "most_recent", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
        "truncateOverrun": "truncate_overrun", 
        "truncateOverrunDelta": "truncate_overrun_delta", 
        "truncateOverrunDeltaAvg": "truncate_overrun_delta_avg", 
        "truncateOverrunDeltaMax": "truncate_overrun_delta_max", 
        "truncateOverrunDeltaMin": "truncate_overrun_delta_min", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.child_action = None
        self.drop_acl = None
        self.drop_acl_delta = None
        self.drop_acl_delta_avg = None
        self.drop_acl_delta_max = None
        self.drop_acl_delta_min = None
        self.drop_overrun = None
        self.drop_overrun_delta = None
        self.drop_overrun_delta_avg = None
        self.drop_overrun_delta_max = None
        self.drop_overrun_delta_min = None
        self.drop_runt = None
        self.drop_runt_delta = None
        self.drop_runt_delta_avg = None
        self.drop_runt_delta_max = None
        self.drop_runt_delta_min = None
        self.most_recent = None
        self.sacl = None
        self.status = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None
        self.truncate_overrun = None
        self.truncate_overrun_delta = None
        self.truncate_overrun_delta_avg = None
        self.truncate_overrun_delta_max = None
        self.truncate_overrun_delta_min = None

        ManagedObject.__init__(self, "AdaptorMenloMcpuStatsHist", parent_mo_or_dn, **kwargs)



"""This module contains the general information for ComputeMbTempStats ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ComputeMbTempStatsConsts:
    FM_TEMP_SEN_IO_NOT_APPLICABLE = "not-applicable"
    FM_TEMP_SEN_IO_AVG_NOT_APPLICABLE = "not-applicable"
    FM_TEMP_SEN_IO_MAX_NOT_APPLICABLE = "not-applicable"
    FM_TEMP_SEN_IO_MIN_NOT_APPLICABLE = "not-applicable"
    FM_TEMP_SEN_REAR_NOT_APPLICABLE = "not-applicable"
    FM_TEMP_SEN_REAR_AVG_NOT_APPLICABLE = "not-applicable"
    FM_TEMP_SEN_REAR_L_NOT_APPLICABLE = "not-applicable"
    FM_TEMP_SEN_REAR_LAVG_NOT_APPLICABLE = "not-applicable"
    FM_TEMP_SEN_REAR_LMAX_NOT_APPLICABLE = "not-applicable"
    FM_TEMP_SEN_REAR_LMIN_NOT_APPLICABLE = "not-applicable"
    FM_TEMP_SEN_REAR_MAX_NOT_APPLICABLE = "not-applicable"
    FM_TEMP_SEN_REAR_MIN_NOT_APPLICABLE = "not-applicable"
    FM_TEMP_SEN_REAR_R_NOT_APPLICABLE = "not-applicable"
    FM_TEMP_SEN_REAR_RAVG_NOT_APPLICABLE = "not-applicable"
    FM_TEMP_SEN_REAR_RMAX_NOT_APPLICABLE = "not-applicable"
    FM_TEMP_SEN_REAR_RMIN_NOT_APPLICABLE = "not-applicable"
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class ComputeMbTempStats(ManagedObject):
    """This is ComputeMbTempStats class."""

    consts = ComputeMbTempStatsConsts()
    naming_props = set([])

    mo_meta = MoMeta("ComputeMbTempStats", "computeMbTempStats", "temp-stats", VersionMeta.Version111j, "OutputOnly", 0xf, [], ["admin", "operations", "read-only"], ['computeBoard', 'computeExtBoard'], ['computeMbTempStatsHist'], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111j, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "fm_temp_sen_io": MoPropertyMeta("fm_temp_sen_io", "fmTempSenIo", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "fm_temp_sen_io_avg": MoPropertyMeta("fm_temp_sen_io_avg", "fmTempSenIoAvg", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "fm_temp_sen_io_max": MoPropertyMeta("fm_temp_sen_io_max", "fmTempSenIoMax", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "fm_temp_sen_io_min": MoPropertyMeta("fm_temp_sen_io_min", "fmTempSenIoMin", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "fm_temp_sen_rear": MoPropertyMeta("fm_temp_sen_rear", "fmTempSenRear", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "fm_temp_sen_rear_avg": MoPropertyMeta("fm_temp_sen_rear_avg", "fmTempSenRearAvg", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "fm_temp_sen_rear_l": MoPropertyMeta("fm_temp_sen_rear_l", "fmTempSenRearL", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "fm_temp_sen_rear_l_avg": MoPropertyMeta("fm_temp_sen_rear_l_avg", "fmTempSenRearLAvg", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "fm_temp_sen_rear_l_max": MoPropertyMeta("fm_temp_sen_rear_l_max", "fmTempSenRearLMax", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "fm_temp_sen_rear_l_min": MoPropertyMeta("fm_temp_sen_rear_l_min", "fmTempSenRearLMin", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "fm_temp_sen_rear_max": MoPropertyMeta("fm_temp_sen_rear_max", "fmTempSenRearMax", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "fm_temp_sen_rear_min": MoPropertyMeta("fm_temp_sen_rear_min", "fmTempSenRearMin", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "fm_temp_sen_rear_r": MoPropertyMeta("fm_temp_sen_rear_r", "fmTempSenRearR", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "fm_temp_sen_rear_r_avg": MoPropertyMeta("fm_temp_sen_rear_r_avg", "fmTempSenRearRAvg", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "fm_temp_sen_rear_r_max": MoPropertyMeta("fm_temp_sen_rear_r_max", "fmTempSenRearRMax", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "fm_temp_sen_rear_r_min": MoPropertyMeta("fm_temp_sen_rear_r_min", "fmTempSenRearRMin", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([123]?[1234]?)([0-9]{0,36})(([.])([0-9]{1,10}))?$""", ["not-applicable"], ["0-4294967295"]),
        "intervals": MoPropertyMeta("intervals", "intervals", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "update": MoPropertyMeta("update", "update", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "fmTempSenIo": "fm_temp_sen_io", 
        "fmTempSenIoAvg": "fm_temp_sen_io_avg", 
        "fmTempSenIoMax": "fm_temp_sen_io_max", 
        "fmTempSenIoMin": "fm_temp_sen_io_min", 
        "fmTempSenRear": "fm_temp_sen_rear", 
        "fmTempSenRearAvg": "fm_temp_sen_rear_avg", 
        "fmTempSenRearL": "fm_temp_sen_rear_l", 
        "fmTempSenRearLAvg": "fm_temp_sen_rear_l_avg", 
        "fmTempSenRearLMax": "fm_temp_sen_rear_l_max", 
        "fmTempSenRearLMin": "fm_temp_sen_rear_l_min", 
        "fmTempSenRearMax": "fm_temp_sen_rear_max", 
        "fmTempSenRearMin": "fm_temp_sen_rear_min", 
        "fmTempSenRearR": "fm_temp_sen_rear_r", 
        "fmTempSenRearRAvg": "fm_temp_sen_rear_r_avg", 
        "fmTempSenRearRMax": "fm_temp_sen_rear_r_max", 
        "fmTempSenRearRMin": "fm_temp_sen_rear_r_min", 
        "intervals": "intervals", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
        "update": "update", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.fm_temp_sen_io = None
        self.fm_temp_sen_io_avg = None
        self.fm_temp_sen_io_max = None
        self.fm_temp_sen_io_min = None
        self.fm_temp_sen_rear = None
        self.fm_temp_sen_rear_avg = None
        self.fm_temp_sen_rear_l = None
        self.fm_temp_sen_rear_l_avg = None
        self.fm_temp_sen_rear_l_max = None
        self.fm_temp_sen_rear_l_min = None
        self.fm_temp_sen_rear_max = None
        self.fm_temp_sen_rear_min = None
        self.fm_temp_sen_rear_r = None
        self.fm_temp_sen_rear_r_avg = None
        self.fm_temp_sen_rear_r_max = None
        self.fm_temp_sen_rear_r_min = None
        self.intervals = None
        self.sacl = None
        self.status = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None
        self.update = None

        ManagedObject.__init__(self, "ComputeMbTempStats", parent_mo_or_dn, **kwargs)



"""This module contains the general information for ComputePciCap ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ComputePciCapConsts:
    ORDER_ASCENDING = "ascending"
    ORDER_ASCENDING_DUAL = "ascending-dual"
    ORDER_ASCENDING_EXTENDED = "ascending-extended"
    ORDER_ASCENDING_SEQ = "ascending-seq"
    ORDER_DESCENDING = "descending"


class ComputePciCap(ManagedObject):
    """This is ComputePciCap class."""

    consts = ComputePciCapConsts()
    naming_props = set([])

    mo_meta = MoMeta("ComputePciCap", "computePciCap", "pci", VersionMeta.Version111j, "InputOutput", 0x1ff, [], ["read-only"], ['equipmentBladeCapProvider', 'equipmentRackUnitCapProvider', 'equipmentServerUnitCapProvider'], ['computePciSlotScanDef'], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111j, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "max_bus_id_per_slot": MoPropertyMeta("max_bus_id_per_slot", "maxBusIdPerSlot", "ushort", VersionMeta.Version204a, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, [], ["0-65535"]),
        "num_of_phys_slots": MoPropertyMeta("num_of_phys_slots", "numOfPhysSlots", "byte", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, [], ["0-255"]),
        "order": MoPropertyMeta("order", "order", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["ascending", "ascending-dual", "ascending-extended", "ascending-seq", "descending"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x40, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "starts_with": MoPropertyMeta("starts_with", "startsWith", "ushort", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, [], ["0-65535"]),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x100, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "maxBusIdPerSlot": "max_bus_id_per_slot", 
        "numOfPhysSlots": "num_of_phys_slots", 
        "order": "order", 
        "rn": "rn", 
        "sacl": "sacl", 
        "startsWith": "starts_with", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.max_bus_id_per_slot = None
        self.num_of_phys_slots = None
        self.order = None
        self.sacl = None
        self.starts_with = None
        self.status = None

        ManagedObject.__init__(self, "ComputePciCap", parent_mo_or_dn, **kwargs)



"""This module contains the meta information of AaaSetupShellAccessInternal ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("AaaSetupShellAccessInternal", "aaaSetupShellAccessInternal", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_id": MethodPropertyMeta("InId", "inId", "Xs:unsignedInt", "Version142b", "Input", False),
    "in_locales": MethodPropertyMeta("InLocales", "inLocales", "Xs:string", "Version142b", "Input", False),
    "in_parent_sess": MethodPropertyMeta("InParentSess", "inParentSess", "Xs:string", "Version142b", "Input", False),
    "in_priv": MethodPropertyMeta("InPriv", "inPriv", "Xs:string", "Version142b", "Input", False),
    "in_remote": MethodPropertyMeta("InRemote", "inRemote", "Xs:string", "Version142b", "Input", False),
    "in_role_list": MethodPropertyMeta("InRoleList", "inRoleList", "Xs:string", "Version142b", "Input", False),
    "in_ssh_key": MethodPropertyMeta("InSshKey", "inSshKey", "Xs:string", "Version142b", "Input", False),
    "in_user": MethodPropertyMeta("InUser", "inUser", "Xs:string", "Version142b", "Input", False),
    "out_out_user": MethodPropertyMeta("OutOutUser", "outOutUser", "Xs:string", "Version142b", "Output", False),
}

prop_map = {
    "cookie": "cookie",
    "inId": "in_id",
    "inLocales": "in_locales",
    "inParentSess": "in_parent_sess",
    "inPriv": "in_priv",
    "inRemote": "in_remote",
    "inRoleList": "in_role_list",
    "inSshKey": "in_ssh_key",
    "inUser": "in_user",
    "outOutUser": "out_out_user",
}



"""This module contains the general information for FabricVlan ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class FabricVlanConsts:
    ASSOC_PRIMARY_VLAN_STATE_DOES_NOT_EXISTS = "does-not-exists"
    ASSOC_PRIMARY_VLAN_STATE_IS_EMPTY = "is-empty"
    ASSOC_PRIMARY_VLAN_STATE_IS_IN_ERROR_STATE = "is-in-error-state"
    ASSOC_PRIMARY_VLAN_STATE_IS_NOT_PRIMARY_TYPE = "is-not-primary-type"
    ASSOC_PRIMARY_VLAN_STATE_OK = "ok"
    ASSOC_PRIMARY_VLAN_SWITCH_ID_A = "A"
    ASSOC_PRIMARY_VLAN_SWITCH_ID_B = "B"
    ASSOC_PRIMARY_VLAN_SWITCH_ID_NONE = "NONE"
    COMPRESSION_TYPE_EXCLUDED = "excluded"
    COMPRESSION_TYPE_INCLUDED = "included"
    CONFIG_OVERLAP_ERROR_RESERVED_CONFLICT = "error-reserved-conflict"
    CONFIG_OVERLAP_OK = "ok"
    DEFAULT_NET_FALSE = "false"
    DEFAULT_NET_NO = "no"
    DEFAULT_NET_TRUE = "true"
    DEFAULT_NET_YES = "yes"
    IF_ROLE_DIAG = "diag"
    IF_ROLE_FCOE_NAS_STORAGE = "fcoe-nas-storage"
    IF_ROLE_FCOE_STORAGE = "fcoe-storage"
    IF_ROLE_FCOE_UPLINK = "fcoe-uplink"
    IF_ROLE_MGMT = "mgmt"
    IF_ROLE_MONITOR = "monitor"
    IF_ROLE_NAS_STORAGE = "nas-storage"
    IF_ROLE_NETWORK = "network"
    IF_ROLE_NETWORK_FCOE_UPLINK = "network-fcoe-uplink"
    IF_ROLE_SERVER = "server"
    IF_ROLE_SERVICE = "service"
    IF_ROLE_STORAGE = "storage"
    IF_ROLE_UNKNOWN = "unknown"
    IF_TYPE_AGGREGATION = "aggregation"
    IF_TYPE_PHYSICAL = "physical"
    IF_TYPE_UNKNOWN = "unknown"
    IF_TYPE_VIRTUAL = "virtual"
    OPER_STATE_ERROR_MISCONFIGURED = "error-misconfigured"
    OPER_STATE_OK = "ok"
    OVERLAP_STATE_FOR_A_ACTIVE = "active"
    OVERLAP_STATE_FOR_A_NOT_ACTIVE = "not-active"
    OVERLAP_STATE_FOR_A_OK = "ok"
    OVERLAP_STATE_FOR_A_PRIMARY_ID_MISMATCH = "primary-id-mismatch"
    OVERLAP_STATE_FOR_A_SHARING_TYPE_MISMATCH = "sharing-type-mismatch"
    OVERLAP_STATE_FOR_B_ACTIVE = "active"
    OVERLAP_STATE_FOR_B_NOT_ACTIVE = "not-active"
    OVERLAP_STATE_FOR_B_OK = "ok"
    OVERLAP_STATE_FOR_B_PRIMARY_ID_MISMATCH = "primary-id-mismatch"
    OVERLAP_STATE_FOR_B_SHARING_TYPE_MISMATCH = "sharing-type-mismatch"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    SHARING_COMMUNITY = "community"
    SHARING_ISOLATED = "isolated"
    SHARING_NONE = "none"
    SHARING_PRIMARY = "primary"
    SWITCH_ID_A = "A"
    SWITCH_ID_B = "B"
    SWITCH_ID_NONE = "NONE"
    SWITCH_ID_DUAL = "dual"


class FabricVlan(ManagedObject):
    """This is FabricVlan class."""

    consts = FabricVlanConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("FabricVlan", "fabricVlan", "net-[name]", VersionMeta.Version101e, "InputOutput", 0x1fff, [], ["admin", "ext-lan-config", "ext-lan-policy"], ['fabricEthEstc', 'fabricEthEstcCloud', 'fabricEthLan', 'fabricLanCloud'], ['fabricEthMonFiltEp', 'fabricEthMonSrcEp', 'fabricEthVlanPc', 'fabricEthVlanPortEp', 'fabricPoolableVlan', 'fabricSwSubGroup', 'faultInst'], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "assoc_primary_vlan_state": MoPropertyMeta("assoc_primary_vlan_state", "assocPrimaryVlanState", "string", VersionMeta.Version222c, MoPropertyMeta.READ_ONLY, None, None, None, None, ["does-not-exists", "is-empty", "is-in-error-state", "is-not-primary-type", "ok"], []),
        "assoc_primary_vlan_switch_id": MoPropertyMeta("assoc_primary_vlan_switch_id", "assocPrimaryVlanSwitchId", "string", VersionMeta.Version222c, MoPropertyMeta.READ_ONLY, None, None, None, None, ["A", "B", "NONE"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "cloud": MoPropertyMeta("cloud", "cloud", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|fcsanmon|ethlan|ethestclan|fcestc|ethlanmon|fcsan),){0,7}(defaultValue|unknown|fcsanmon|ethlan|ethestclan|fcestc|ethlanmon|fcsan){0,1}""", [], []),
        "compression_type": MoPropertyMeta("compression_type", "compressionType", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, ["excluded", "included"], []),
        "config_issues": MoPropertyMeta("config_issues", "configIssues", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|not-applicable|conflicting-vlan-access|unsupported-multicast-policy),){0,3}(defaultValue|not-applicable|conflicting-vlan-access|unsupported-multicast-policy){0,1}""", [], []),
        "config_overlap": MoPropertyMeta("config_overlap", "configOverlap", "string", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["error-reserved-conflict", "ok"], []),
        "default_net": MoPropertyMeta("default_net", "defaultNet", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, ["false", "no", "true", "yes"], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "ep_dn": MoPropertyMeta("ep_dn", "epDn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "flt_aggr": MoPropertyMeta("flt_aggr", "fltAggr", "ulong", VersionMeta.Version211a, MoPropertyMeta.INTERNAL, None, None, None, None, [], []),
        "r_global": MoPropertyMeta("r_global", "global", "ulong", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, [], ["1-4042", "4048-4093"]),
        "if_role": MoPropertyMeta("if_role", "ifRole", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["diag", "fcoe-nas-storage", "fcoe-storage", "fcoe-uplink", "mgmt", "monitor", "nas-storage", "network", "network-fcoe-uplink", "server", "service", "storage", "unknown"], []),
        "if_type": MoPropertyMeta("if_type", "ifType", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["aggregation", "physical", "unknown", "virtual"], []),
        "local": MoPropertyMeta("local", "local", "ulong", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "locale": MoPropertyMeta("locale", "locale", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|server|chassis|internal|external),){0,5}(defaultValue|unknown|server|chassis|internal|external){0,1}""", [], []),
        "mcast_policy_name": MoPropertyMeta("mcast_policy_name", "mcastPolicyName", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x80, None, None, r"""[\-\.:_a-zA-Z0-9]{1,32}""", [], []),
        "oper_mcast_policy_name": MoPropertyMeta("oper_mcast_policy_name", "operMcastPolicyName", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["error-misconfigured", "ok"], []),
        "overlap_state_for_a": MoPropertyMeta("overlap_state_for_a", "overlapStateForA", "string", VersionMeta.Version222c, MoPropertyMeta.READ_ONLY, None, None, None, None, ["active", "not-active", "ok", "primary-id-mismatch", "sharing-type-mismatch"], []),
        "overlap_state_for_b": MoPropertyMeta("overlap_state_for_b", "overlapStateForB", "string", VersionMeta.Version222c, MoPropertyMeta.READ_ONLY, None, None, None, None, ["active", "not-active", "ok", "primary-id-mismatch", "sharing-type-mismatch"], []),
        "peer_dn": MoPropertyMeta("peer_dn", "peerDn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version212a, MoPropertyMeta.READ_WRITE, 0x100, None, None, None, ["local", "pending-policy", "policy"], []),
        "pub_nw_dn": MoPropertyMeta("pub_nw_dn", "pubNwDn", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "pub_nw_id": MoPropertyMeta("pub_nw_id", "pubNwId", "uint", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pub_nw_name": MoPropertyMeta("pub_nw_name", "pubNwName", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x200, 0, 510, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x400, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "sharing": MoPropertyMeta("sharing", "sharing", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x800, None, None, None, ["community", "isolated", "none", "primary"], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x1000, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "switch_id": MoPropertyMeta("switch_id", "switchId", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["A", "B", "NONE", "dual"], []),
        "transport": MoPropertyMeta("transport", "transport", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|ether|dce|fc),){0,4}(defaultValue|unknown|ether|dce|fc){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|lan|san|ipc),){0,4}(defaultValue|unknown|lan|san|ipc){0,1}""", [], []),
    }

    prop_map = {
        "assocPrimaryVlanState": "assoc_primary_vlan_state", 
        "assocPrimaryVlanSwitchId": "assoc_primary_vlan_switch_id", 
        "childAction": "child_action", 
        "cloud": "cloud", 
        "compressionType": "compression_type", 
        "configIssues": "config_issues", 
        "configOverlap": "config_overlap", 
        "defaultNet": "default_net", 
        "dn": "dn", 
        "epDn": "ep_dn", 
        "fltAggr": "flt_aggr", 
        "global": "r_global", 
        "id": "id", 
        "ifRole": "if_role", 
        "ifType": "if_type", 
        "local": "local", 
        "locale": "locale", 
        "mcastPolicyName": "mcast_policy_name", 
        "name": "name", 
        "operMcastPolicyName": "oper_mcast_policy_name", 
        "operState": "oper_state", 
        "overlapStateForA": "overlap_state_for_a", 
        "overlapStateForB": "overlap_state_for_b", 
        "peerDn": "peer_dn", 
        "policyOwner": "policy_owner", 
        "pubNwDn": "pub_nw_dn", 
        "pubNwId": "pub_nw_id", 
        "pubNwName": "pub_nw_name", 
        "rn": "rn", 
        "sacl": "sacl", 
        "sharing": "sharing", 
        "status": "status", 
        "switchId": "switch_id", 
        "transport": "transport", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.assoc_primary_vlan_state = None
        self.assoc_primary_vlan_switch_id = None
        self.child_action = None
        self.cloud = None
        self.compression_type = None
        self.config_issues = None
        self.config_overlap = None
        self.default_net = None
        self.ep_dn = None
        self.flt_aggr = None
        self.r_global = None
        self.id = None
        self.if_role = None
        self.if_type = None
        self.local = None
        self.locale = None
        self.mcast_policy_name = None
        self.oper_mcast_policy_name = None
        self.oper_state = None
        self.overlap_state_for_a = None
        self.overlap_state_for_b = None
        self.peer_dn = None
        self.policy_owner = None
        self.pub_nw_dn = None
        self.pub_nw_id = None
        self.pub_nw_name = None
        self.sacl = None
        self.sharing = None
        self.status = None
        self.switch_id = None
        self.transport = None
        self.type = None

        ManagedObject.__init__(self, "FabricVlan", parent_mo_or_dn, **kwargs)



"""This module contains the general information for BiosVfPCISlotOptionROMEnable ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class BiosVfPCISlotOptionROMEnableConsts:
    SUPPORTED_BY_DEFAULT_NO = "no"
    SUPPORTED_BY_DEFAULT_YES = "yes"
    VP_PCIE_SLOT_HBAOPTION_ROM_DISABLED = "disabled"
    VP_PCIE_SLOT_HBAOPTION_ROM_ENABLED = "enabled"
    VP_PCIE_SLOT_HBAOPTION_ROM_LEGACY_ONLY = "legacy-only"
    VP_PCIE_SLOT_HBAOPTION_ROM_PLATFORM_DEFAULT = "platform-default"
    VP_PCIE_SLOT_HBAOPTION_ROM_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_PCIE_SLOT_HBAOPTION_ROM_UEFI_ONLY = "uefi-only"
    VP_PCIE_SLOT_MLOMOPTION_ROM_DISABLED = "disabled"
    VP_PCIE_SLOT_MLOMOPTION_ROM_ENABLED = "enabled"
    VP_PCIE_SLOT_MLOMOPTION_ROM_LEGACY_ONLY = "legacy-only"
    VP_PCIE_SLOT_MLOMOPTION_ROM_PLATFORM_DEFAULT = "platform-default"
    VP_PCIE_SLOT_MLOMOPTION_ROM_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_PCIE_SLOT_MLOMOPTION_ROM_UEFI_ONLY = "uefi-only"
    VP_PCIE_SLOT_N1_OPTION_ROM_DISABLED = "disabled"
    VP_PCIE_SLOT_N1_OPTION_ROM_ENABLED = "enabled"
    VP_PCIE_SLOT_N1_OPTION_ROM_LEGACY_ONLY = "legacy-only"
    VP_PCIE_SLOT_N1_OPTION_ROM_PLATFORM_DEFAULT = "platform-default"
    VP_PCIE_SLOT_N1_OPTION_ROM_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_PCIE_SLOT_N1_OPTION_ROM_UEFI_ONLY = "uefi-only"
    VP_PCIE_SLOT_N2_OPTION_ROM_DISABLED = "disabled"
    VP_PCIE_SLOT_N2_OPTION_ROM_ENABLED = "enabled"
    VP_PCIE_SLOT_N2_OPTION_ROM_LEGACY_ONLY = "legacy-only"
    VP_PCIE_SLOT_N2_OPTION_ROM_PLATFORM_DEFAULT = "platform-default"
    VP_PCIE_SLOT_N2_OPTION_ROM_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_PCIE_SLOT_N2_OPTION_ROM_UEFI_ONLY = "uefi-only"
    VP_PCIE_SLOT_SASOPTION_ROM_DISABLED = "disabled"
    VP_PCIE_SLOT_SASOPTION_ROM_ENABLED = "enabled"
    VP_PCIE_SLOT_SASOPTION_ROM_LEGACY_ONLY = "legacy-only"
    VP_PCIE_SLOT_SASOPTION_ROM_PLATFORM_DEFAULT = "platform-default"
    VP_PCIE_SLOT_SASOPTION_ROM_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_PCIE_SLOT_SASOPTION_ROM_UEFI_ONLY = "uefi-only"
    VP_SLOT10_STATE_DISABLED = "disabled"
    VP_SLOT10_STATE_ENABLED = "enabled"
    VP_SLOT10_STATE_LEGACY_ONLY = "legacy-only"
    VP_SLOT10_STATE_PLATFORM_DEFAULT = "platform-default"
    VP_SLOT10_STATE_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_SLOT10_STATE_UEFI_ONLY = "uefi-only"
    VP_SLOT1_STATE_DISABLED = "disabled"
    VP_SLOT1_STATE_ENABLED = "enabled"
    VP_SLOT1_STATE_LEGACY_ONLY = "legacy-only"
    VP_SLOT1_STATE_PLATFORM_DEFAULT = "platform-default"
    VP_SLOT1_STATE_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_SLOT1_STATE_UEFI_ONLY = "uefi-only"
    VP_SLOT2_STATE_DISABLED = "disabled"
    VP_SLOT2_STATE_ENABLED = "enabled"
    VP_SLOT2_STATE_LEGACY_ONLY = "legacy-only"
    VP_SLOT2_STATE_PLATFORM_DEFAULT = "platform-default"
    VP_SLOT2_STATE_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_SLOT2_STATE_UEFI_ONLY = "uefi-only"
    VP_SLOT3_STATE_DISABLED = "disabled"
    VP_SLOT3_STATE_ENABLED = "enabled"
    VP_SLOT3_STATE_LEGACY_ONLY = "legacy-only"
    VP_SLOT3_STATE_PLATFORM_DEFAULT = "platform-default"
    VP_SLOT3_STATE_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_SLOT3_STATE_UEFI_ONLY = "uefi-only"
    VP_SLOT4_STATE_DISABLED = "disabled"
    VP_SLOT4_STATE_ENABLED = "enabled"
    VP_SLOT4_STATE_LEGACY_ONLY = "legacy-only"
    VP_SLOT4_STATE_PLATFORM_DEFAULT = "platform-default"
    VP_SLOT4_STATE_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_SLOT4_STATE_UEFI_ONLY = "uefi-only"
    VP_SLOT5_STATE_DISABLED = "disabled"
    VP_SLOT5_STATE_ENABLED = "enabled"
    VP_SLOT5_STATE_LEGACY_ONLY = "legacy-only"
    VP_SLOT5_STATE_PLATFORM_DEFAULT = "platform-default"
    VP_SLOT5_STATE_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_SLOT5_STATE_UEFI_ONLY = "uefi-only"
    VP_SLOT6_STATE_DISABLED = "disabled"
    VP_SLOT6_STATE_ENABLED = "enabled"
    VP_SLOT6_STATE_LEGACY_ONLY = "legacy-only"
    VP_SLOT6_STATE_PLATFORM_DEFAULT = "platform-default"
    VP_SLOT6_STATE_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_SLOT6_STATE_UEFI_ONLY = "uefi-only"
    VP_SLOT7_STATE_DISABLED = "disabled"
    VP_SLOT7_STATE_ENABLED = "enabled"
    VP_SLOT7_STATE_LEGACY_ONLY = "legacy-only"
    VP_SLOT7_STATE_PLATFORM_DEFAULT = "platform-default"
    VP_SLOT7_STATE_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_SLOT7_STATE_UEFI_ONLY = "uefi-only"
    VP_SLOT8_STATE_DISABLED = "disabled"
    VP_SLOT8_STATE_ENABLED = "enabled"
    VP_SLOT8_STATE_LEGACY_ONLY = "legacy-only"
    VP_SLOT8_STATE_PLATFORM_DEFAULT = "platform-default"
    VP_SLOT8_STATE_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_SLOT8_STATE_UEFI_ONLY = "uefi-only"
    VP_SLOT9_STATE_DISABLED = "disabled"
    VP_SLOT9_STATE_ENABLED = "enabled"
    VP_SLOT9_STATE_LEGACY_ONLY = "legacy-only"
    VP_SLOT9_STATE_PLATFORM_DEFAULT = "platform-default"
    VP_SLOT9_STATE_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_SLOT9_STATE_UEFI_ONLY = "uefi-only"
    VP_SLOT_MEZZ_STATE_DISABLED = "disabled"
    VP_SLOT_MEZZ_STATE_ENABLED = "enabled"
    VP_SLOT_MEZZ_STATE_LEGACY_ONLY = "legacy-only"
    VP_SLOT_MEZZ_STATE_PLATFORM_DEFAULT = "platform-default"
    VP_SLOT_MEZZ_STATE_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_SLOT_MEZZ_STATE_UEFI_ONLY = "uefi-only"


class BiosVfPCISlotOptionROMEnable(ManagedObject):
    """This is BiosVfPCISlotOptionROMEnable class."""

    consts = BiosVfPCISlotOptionROMEnableConsts()
    naming_props = set([])

    mo_meta = MoMeta("BiosVfPCISlotOptionROMEnable", "biosVfPCISlotOptionROMEnable", "PCI-Slot-OptionROM-Enable", VersionMeta.Version202m, "InputOutput", 0xfffff, [], ["admin", "ls-compute", "ls-config", "ls-server", "ls-server-policy", "pn-policy"], ['biosSettings', 'biosVProfile'], [], ["Get", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version202m, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version202m, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "prop_acl": MoPropertyMeta("prop_acl", "propAcl", "ulong", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version202m, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version202m, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "supported_by_default": MoPropertyMeta("supported_by_default", "supportedByDefault", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, ["no", "yes"], []),
        "vp_pc_ie_slot_hba_option_rom": MoPropertyMeta("vp_pc_ie_slot_hba_option_rom", "vpPCIeSlotHBAOptionROM", "string", VersionMeta.Version223a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["disabled", "enabled", "legacy-only", "platform-default", "platform-recommended", "uefi-only"], []),
        "vp_pc_ie_slot_mlom_option_rom": MoPropertyMeta("vp_pc_ie_slot_mlom_option_rom", "vpPCIeSlotMLOMOptionROM", "string", VersionMeta.Version223a, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, ["disabled", "enabled", "legacy-only", "platform-default", "platform-recommended", "uefi-only"], []),
        "vp_pc_ie_slot_n1_option_rom": MoPropertyMeta("vp_pc_ie_slot_n1_option_rom", "vpPCIeSlotN1OptionROM", "string", VersionMeta.Version223a, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, ["disabled", "enabled", "legacy-only", "platform-default", "platform-recommended", "uefi-only"], []),
        "vp_pc_ie_slot_n2_option_rom": MoPropertyMeta("vp_pc_ie_slot_n2_option_rom", "vpPCIeSlotN2OptionROM", "string", VersionMeta.Version223a, MoPropertyMeta.READ_WRITE, 0x100, None, None, None, ["disabled", "enabled", "legacy-only", "platform-default", "platform-recommended", "uefi-only"], []),
        "vp_pc_ie_slot_sas_option_rom": MoPropertyMeta("vp_pc_ie_slot_sas_option_rom", "vpPCIeSlotSASOptionROM", "string", VersionMeta.Version222c, MoPropertyMeta.READ_WRITE, 0x200, None, None, None, ["disabled", "enabled", "legacy-only", "platform-default", "platform-recommended", "uefi-only"], []),
        "vp_slot10_state": MoPropertyMeta("vp_slot10_state", "vpSlot10State", "string", VersionMeta.Version222c, MoPropertyMeta.READ_WRITE, 0x400, None, None, None, ["disabled", "enabled", "legacy-only", "platform-default", "platform-recommended", "uefi-only"], []),
        "vp_slot1_state": MoPropertyMeta("vp_slot1_state", "vpSlot1State", "string", VersionMeta.Version202m, MoPropertyMeta.READ_WRITE, 0x800, None, None, None, ["disabled", "enabled", "legacy-only", "platform-default", "platform-recommended", "uefi-only"], []),
        "vp_slot2_state": MoPropertyMeta("vp_slot2_state", "vpSlot2State", "string", VersionMeta.Version202m, MoPropertyMeta.READ_WRITE, 0x1000, None, None, None, ["disabled", "enabled", "legacy-only", "platform-default", "platform-recommended", "uefi-only"], []),
        "vp_slot3_state": MoPropertyMeta("vp_slot3_state", "vpSlot3State", "string", VersionMeta.Version202m, MoPropertyMeta.READ_WRITE, 0x2000, None, None, None, ["disabled", "enabled", "legacy-only", "platform-default", "platform-recommended", "uefi-only"], []),
        "vp_slot4_state": MoPropertyMeta("vp_slot4_state", "vpSlot4State", "string", VersionMeta.Version202m, MoPropertyMeta.READ_WRITE, 0x4000, None, None, None, ["disabled", "enabled", "legacy-only", "platform-default", "platform-recommended", "uefi-only"], []),
        "vp_slot5_state": MoPropertyMeta("vp_slot5_state", "vpSlot5State", "string", VersionMeta.Version202m, MoPropertyMeta.READ_WRITE, 0x8000, None, None, None, ["disabled", "enabled", "legacy-only", "platform-default", "platform-recommended", "uefi-only"], []),
        "vp_slot6_state": MoPropertyMeta("vp_slot6_state", "vpSlot6State", "string", VersionMeta.Version212a, MoPropertyMeta.READ_WRITE, 0x10000, None, None, None, ["disabled", "enabled", "legacy-only", "platform-default", "platform-recommended", "uefi-only"], []),
        "vp_slot7_state": MoPropertyMeta("vp_slot7_state", "vpSlot7State", "string", VersionMeta.Version212a, MoPropertyMeta.READ_WRITE, 0x20000, None, None, None, ["disabled", "enabled", "legacy-only", "platform-default", "platform-recommended", "uefi-only"], []),
        "vp_slot8_state": MoPropertyMeta("vp_slot8_state", "vpSlot8State", "string", VersionMeta.Version222c, MoPropertyMeta.READ_WRITE, 0x40000, None, None, None, ["disabled", "enabled", "legacy-only", "platform-default", "platform-recommended", "uefi-only"], []),
        "vp_slot9_state": MoPropertyMeta("vp_slot9_state", "vpSlot9State", "string", VersionMeta.Version222c, MoPropertyMeta.READ_WRITE, 0x80000, None, None, None, ["disabled", "enabled", "legacy-only", "platform-default", "platform-recommended", "uefi-only"], []),
        "vp_slot_mezz_state": MoPropertyMeta("vp_slot_mezz_state", "vpSlotMezzState", "string", VersionMeta.Version202m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["disabled", "enabled", "legacy-only", "platform-default", "platform-recommended", "uefi-only"], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "propAcl": "prop_acl", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "supportedByDefault": "supported_by_default", 
        "vpPCIeSlotHBAOptionROM": "vp_pc_ie_slot_hba_option_rom", 
        "vpPCIeSlotMLOMOptionROM": "vp_pc_ie_slot_mlom_option_rom", 
        "vpPCIeSlotN1OptionROM": "vp_pc_ie_slot_n1_option_rom", 
        "vpPCIeSlotN2OptionROM": "vp_pc_ie_slot_n2_option_rom", 
        "vpPCIeSlotSASOptionROM": "vp_pc_ie_slot_sas_option_rom", 
        "vpSlot10State": "vp_slot10_state", 
        "vpSlot1State": "vp_slot1_state", 
        "vpSlot2State": "vp_slot2_state", 
        "vpSlot3State": "vp_slot3_state", 
        "vpSlot4State": "vp_slot4_state", 
        "vpSlot5State": "vp_slot5_state", 
        "vpSlot6State": "vp_slot6_state", 
        "vpSlot7State": "vp_slot7_state", 
        "vpSlot8State": "vp_slot8_state", 
        "vpSlot9State": "vp_slot9_state", 
        "vpSlotMezzState": "vp_slot_mezz_state", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.prop_acl = None
        self.sacl = None
        self.status = None
        self.supported_by_default = None
        self.vp_pc_ie_slot_hba_option_rom = None
        self.vp_pc_ie_slot_mlom_option_rom = None
        self.vp_pc_ie_slot_n1_option_rom = None
        self.vp_pc_ie_slot_n2_option_rom = None
        self.vp_pc_ie_slot_sas_option_rom = None
        self.vp_slot10_state = None
        self.vp_slot1_state = None
        self.vp_slot2_state = None
        self.vp_slot3_state = None
        self.vp_slot4_state = None
        self.vp_slot5_state = None
        self.vp_slot6_state = None
        self.vp_slot7_state = None
        self.vp_slot8_state = None
        self.vp_slot9_state = None
        self.vp_slot_mezz_state = None

        ManagedObject.__init__(self, "BiosVfPCISlotOptionROMEnable", parent_mo_or_dn, **kwargs)



"""This module contains the general information for LstorageControllerQualifier ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class LstorageControllerQualifierConsts:
    CONTROLLER_ID_ALL = "all"
    CONTROLLER_TYPE_FLASH = "FLASH"
    CONTROLLER_TYPE_HBA = "HBA"
    CONTROLLER_TYPE_M2 = "M2"
    CONTROLLER_TYPE_NVME = "NVME"
    CONTROLLER_TYPE_PCH = "PCH"
    CONTROLLER_TYPE_PT = "PT"
    CONTROLLER_TYPE_SAS = "SAS"
    CONTROLLER_TYPE_SATA = "SATA"
    CONTROLLER_TYPE_SD = "SD"
    CONTROLLER_TYPE_EXTERNAL = "external"
    CONTROLLER_TYPE_UNKNOWN = "unknown"


class LstorageControllerQualifier(ManagedObject):
    """This is LstorageControllerQualifier class."""

    consts = LstorageControllerQualifierConsts()
    naming_props = set([])

    mo_meta = MoMeta("LstorageControllerQualifier", "lstorageControllerQualifier", "controller-qual", VersionMeta.Version227b, "InputOutput", 0x7f, [], ["admin", "ls-compute", "ls-config", "ls-config-policy", "ls-server", "ls-storage", "ls-storage-policy"], ['lstorageControllerDef'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version227b, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "controller_id": MoPropertyMeta("controller_id", "controllerId", "string", VersionMeta.Version227b, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, ["all"], []),
        "controller_type": MoPropertyMeta("controller_type", "controllerType", "string", VersionMeta.Version227b, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, ["FLASH", "HBA", "M2", "NVME", "PCH", "PT", "SAS", "SATA", "SD", "external", "unknown"], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version227b, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version227b, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version311e, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version227b, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "controllerId": "controller_id", 
        "controllerType": "controller_type", 
        "dn": "dn", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.controller_id = None
        self.controller_type = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "LstorageControllerQualifier", parent_mo_or_dn, **kwargs)



"""This module contains the general information for LsVersionBeh ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class LsVersionBehConsts:
    PCI_ENUM_MULTI_FUNC_ALL = "multi-func-all"
    PCI_ENUM_STATIC_ZERO_FUNC = "static-zero-func"
    PCI_ENUM_ZERO_FUNC_ALL = "zero-func-all"
    VCON_MAP_LINEAR_ORDERED = "linear-ordered"
    VCON_MAP_LINEAR_ORDERED_TO_ROUND_ROBIN = "linear-ordered-to-round-robin"
    VCON_MAP_ROUND_ROBIN = "round-robin"
    VCON_MAP_ROUND_ROBIN_TO_LINEAR_ORDERED = "round-robin-to-linear-ordered"
    VNIC_MAP_CAP_LOAD_DISTRIBUTE = "cap-load-distribute"
    VNIC_MAP_PHYSICAL_CAP_FIRST = "physical-cap-first"
    VNIC_ORDER_ALL_VNIC = "all-vnic"
    VNIC_ORDER_DYNAMIC_ALL_LAST = "dynamic-all-last"
    VNIC_ORDER_STATIC_ALL_FIRST = "static-all-first"


class LsVersionBeh(ManagedObject):
    """This is LsVersionBeh class."""

    consts = LsVersionBehConsts()
    naming_props = set([])

    mo_meta = MoMeta("LsVersionBeh", "lsVersionBeh", "ls-vers-beh", VersionMeta.Version201q, "InputOutput", 0x1ff, [], ["admin"], ['lsServer'], [], ["Get", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version201q, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version201q, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "pci_enum": MoPropertyMeta("pci_enum", "pciEnum", "string", VersionMeta.Version201q, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, ["multi-func-all", "static-zero-func", "zero-func-all"], []),
        "prop_acl": MoPropertyMeta("prop_acl", "propAcl", "ulong", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version201q, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version201q, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "vcon_map": MoPropertyMeta("vcon_map", "vconMap", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, ["linear-ordered", "linear-ordered-to-round-robin", "round-robin", "round-robin-to-linear-ordered"], []),
        "vnic_map": MoPropertyMeta("vnic_map", "vnicMap", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, ["cap-load-distribute", "physical-cap-first"], []),
        "vnic_order": MoPropertyMeta("vnic_order", "vnicOrder", "string", VersionMeta.Version203a, MoPropertyMeta.READ_WRITE, 0x100, None, None, None, ["all-vnic", "dynamic-all-last", "static-all-first"], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "pciEnum": "pci_enum", 
        "propAcl": "prop_acl", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "vconMap": "vcon_map", 
        "vnicMap": "vnic_map", 
        "vnicOrder": "vnic_order", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.pci_enum = None
        self.prop_acl = None
        self.sacl = None
        self.status = None
        self.vcon_map = None
        self.vnic_map = None
        self.vnic_order = None

        ManagedObject.__init__(self, "LsVersionBeh", parent_mo_or_dn, **kwargs)



"""This module contains the general information for AdaptorFcErrorRecoveryProfile ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class AdaptorFcErrorRecoveryProfileConsts:
    FCP_ERROR_RECOVERY_DISABLED = "disabled"
    FCP_ERROR_RECOVERY_ENABLED = "enabled"


class AdaptorFcErrorRecoveryProfile(ManagedObject):
    """This is AdaptorFcErrorRecoveryProfile class."""

    consts = AdaptorFcErrorRecoveryProfileConsts()
    naming_props = set([])

    mo_meta = MoMeta("AdaptorFcErrorRecoveryProfile", "adaptorFcErrorRecoveryProfile", "fc-err-rec", VersionMeta.Version101e, "InputOutput", 0x1ff, [], ["admin", "ls-config-policy", "ls-server-policy", "ls-storage"], ['adaptorHostFcIf', 'adaptorHostFcIfProfile'], [], ["Get", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "error_detect_timeout": MoPropertyMeta("error_detect_timeout", "errorDetectTimeout", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
        "fcp_error_recovery": MoPropertyMeta("fcp_error_recovery", "fcpErrorRecovery", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, ["disabled", "enabled"], []),
        "link_down_timeout": MoPropertyMeta("link_down_timeout", "linkDownTimeout", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, [], ["0-240000"]),
        "port_down_io_retry_count": MoPropertyMeta("port_down_io_retry_count", "portDownIoRetryCount", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, [], ["0-255"]),
        "port_down_timeout": MoPropertyMeta("port_down_timeout", "portDownTimeout", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, [], ["0-240000"]),
        "resource_allocation_timeout": MoPropertyMeta("resource_allocation_timeout", "resourceAllocationTimeout", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x80, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x100, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "errorDetectTimeout": "error_detect_timeout", 
        "fcpErrorRecovery": "fcp_error_recovery", 
        "linkDownTimeout": "link_down_timeout", 
        "portDownIoRetryCount": "port_down_io_retry_count", 
        "portDownTimeout": "port_down_timeout", 
        "resourceAllocationTimeout": "resource_allocation_timeout", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.error_detect_timeout = None
        self.fcp_error_recovery = None
        self.link_down_timeout = None
        self.port_down_io_retry_count = None
        self.port_down_timeout = None
        self.resource_allocation_timeout = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "AdaptorFcErrorRecoveryProfile", parent_mo_or_dn, **kwargs)



"""This module contains the general information for AdaptorMenloFcErrorStats ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class AdaptorMenloFcErrorStatsConsts:
    MENLO_FC_INDEX_0 = "0"
    MENLO_FC_INDEX_0_A = "0_A"
    MENLO_FC_INDEX_0_B = "0_B"
    MENLO_FC_INDEX_1 = "1"
    MENLO_FC_INDEX_1_A = "1_A"
    MENLO_FC_INDEX_1_B = "1_B"
    MENLO_FC_INDEX_UNKNOWN = "unknown"
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class AdaptorMenloFcErrorStats(ManagedObject):
    """This is AdaptorMenloFcErrorStats class."""

    consts = AdaptorMenloFcErrorStatsConsts()
    naming_props = set(['menloFcIndex'])

    mo_meta = MoMeta("AdaptorMenloFcErrorStats", "adaptorMenloFcErrorStats", "menlo-fc-error-stats-[menlo_fc_index]", VersionMeta.Version111j, "OutputOnly", 0xf, [], ["admin", "operations", "read-only"], ['adaptorUnit'], ['adaptorMenloFcErrorStatsHist'], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111j, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "correctable_errors": MoPropertyMeta("correctable_errors", "correctableErrors", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "correctable_errors_delta": MoPropertyMeta("correctable_errors_delta", "correctableErrorsDelta", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "correctable_errors_delta_avg": MoPropertyMeta("correctable_errors_delta_avg", "correctableErrorsDeltaAvg", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "correctable_errors_delta_max": MoPropertyMeta("correctable_errors_delta_max", "correctableErrorsDeltaMax", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "correctable_errors_delta_min": MoPropertyMeta("correctable_errors_delta_min", "correctableErrorsDeltaMin", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "intervals": MoPropertyMeta("intervals", "intervals", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "menlo_fc_index": MoPropertyMeta("menlo_fc_index", "menloFcIndex", "string", VersionMeta.Version111j, MoPropertyMeta.NAMING, None, None, None, None, ["0", "0_A", "0_B", "1", "1_A", "1_B", "unknown"], []),
        "pop_errors": MoPropertyMeta("pop_errors", "popErrors", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pop_errors_delta": MoPropertyMeta("pop_errors_delta", "popErrorsDelta", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pop_errors_delta_avg": MoPropertyMeta("pop_errors_delta_avg", "popErrorsDeltaAvg", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pop_errors_delta_max": MoPropertyMeta("pop_errors_delta_max", "popErrorsDeltaMax", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pop_errors_delta_min": MoPropertyMeta("pop_errors_delta_min", "popErrorsDeltaMin", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "push_errors": MoPropertyMeta("push_errors", "pushErrors", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "push_errors_delta": MoPropertyMeta("push_errors_delta", "pushErrorsDelta", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "push_errors_delta_avg": MoPropertyMeta("push_errors_delta_avg", "pushErrorsDeltaAvg", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "push_errors_delta_max": MoPropertyMeta("push_errors_delta_max", "pushErrorsDeltaMax", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "push_errors_delta_min": MoPropertyMeta("push_errors_delta_min", "pushErrorsDeltaMin", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "uncorrectable_errors": MoPropertyMeta("uncorrectable_errors", "uncorrectableErrors", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "uncorrectable_errors_delta": MoPropertyMeta("uncorrectable_errors_delta", "uncorrectableErrorsDelta", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "uncorrectable_errors_delta_avg": MoPropertyMeta("uncorrectable_errors_delta_avg", "uncorrectableErrorsDeltaAvg", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "uncorrectable_errors_delta_max": MoPropertyMeta("uncorrectable_errors_delta_max", "uncorrectableErrorsDeltaMax", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "uncorrectable_errors_delta_min": MoPropertyMeta("uncorrectable_errors_delta_min", "uncorrectableErrorsDeltaMin", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "update": MoPropertyMeta("update", "update", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "correctableErrors": "correctable_errors", 
        "correctableErrorsDelta": "correctable_errors_delta", 
        "correctableErrorsDeltaAvg": "correctable_errors_delta_avg", 
        "correctableErrorsDeltaMax": "correctable_errors_delta_max", 
        "correctableErrorsDeltaMin": "correctable_errors_delta_min", 
        "dn": "dn", 
        "intervals": "intervals", 
        "menloFcIndex": "menlo_fc_index", 
        "popErrors": "pop_errors", 
        "popErrorsDelta": "pop_errors_delta", 
        "popErrorsDeltaAvg": "pop_errors_delta_avg", 
        "popErrorsDeltaMax": "pop_errors_delta_max", 
        "popErrorsDeltaMin": "pop_errors_delta_min", 
        "pushErrors": "push_errors", 
        "pushErrorsDelta": "push_errors_delta", 
        "pushErrorsDeltaAvg": "push_errors_delta_avg", 
        "pushErrorsDeltaMax": "push_errors_delta_max", 
        "pushErrorsDeltaMin": "push_errors_delta_min", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
        "uncorrectableErrors": "uncorrectable_errors", 
        "uncorrectableErrorsDelta": "uncorrectable_errors_delta", 
        "uncorrectableErrorsDeltaAvg": "uncorrectable_errors_delta_avg", 
        "uncorrectableErrorsDeltaMax": "uncorrectable_errors_delta_max", 
        "uncorrectableErrorsDeltaMin": "uncorrectable_errors_delta_min", 
        "update": "update", 
    }

    def __init__(self, parent_mo_or_dn, menlo_fc_index, **kwargs):
        self._dirty_mask = 0
        self.menlo_fc_index = menlo_fc_index
        self.child_action = None
        self.correctable_errors = None
        self.correctable_errors_delta = None
        self.correctable_errors_delta_avg = None
        self.correctable_errors_delta_max = None
        self.correctable_errors_delta_min = None
        self.intervals = None
        self.pop_errors = None
        self.pop_errors_delta = None
        self.pop_errors_delta_avg = None
        self.pop_errors_delta_max = None
        self.pop_errors_delta_min = None
        self.push_errors = None
        self.push_errors_delta = None
        self.push_errors_delta_avg = None
        self.push_errors_delta_max = None
        self.push_errors_delta_min = None
        self.sacl = None
        self.status = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None
        self.uncorrectable_errors = None
        self.uncorrectable_errors_delta = None
        self.uncorrectable_errors_delta_avg = None
        self.uncorrectable_errors_delta_max = None
        self.uncorrectable_errors_delta_min = None
        self.update = None

        ManagedObject.__init__(self, "AdaptorMenloFcErrorStats", parent_mo_or_dn, **kwargs)



"""This module contains the general information for AdaptorFamilyTypeDef ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class AdaptorFamilyTypeDefConsts:
    IS_MULTI_PORT_FALSE = "false"
    IS_MULTI_PORT_NO = "no"
    IS_MULTI_PORT_TRUE = "true"
    IS_MULTI_PORT_YES = "yes"
    IS_PASSTHROUGH_FALSE = "false"
    IS_PASSTHROUGH_NO = "no"
    IS_PASSTHROUGH_TRUE = "true"
    IS_PASSTHROUGH_YES = "yes"
    IS_RETIMER_REQUIRED_FALSE = "false"
    IS_RETIMER_REQUIRED_NO = "no"
    IS_RETIMER_REQUIRED_TRUE = "true"
    IS_RETIMER_REQUIRED_YES = "yes"


class AdaptorFamilyTypeDef(ManagedObject):
    """This is AdaptorFamilyTypeDef class."""

    consts = AdaptorFamilyTypeDefConsts()
    naming_props = set([])

    mo_meta = MoMeta("AdaptorFamilyTypeDef", "adaptorFamilyTypeDef", "family-type", VersionMeta.Version202m, "InputOutput", 0x7ff, [], ["read-only"], ['adaptorFruCapProvider', 'equipmentLocalDiskControllerCapProvider'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version202m, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version202m, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "is_multi_port": MoPropertyMeta("is_multi_port", "isMultiPort", "string", VersionMeta.Version224b, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, ["false", "no", "true", "yes"], []),
        "is_passthrough": MoPropertyMeta("is_passthrough", "isPassthrough", "string", VersionMeta.Version202m, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["false", "no", "true", "yes"], []),
        "is_retimer_required": MoPropertyMeta("is_retimer_required", "isRetimerRequired", "string", VersionMeta.Version311e, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["false", "no", "true", "yes"], []),
        "num_dce_ports": MoPropertyMeta("num_dce_ports", "numDcePorts", "uint", VersionMeta.Version202m, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, [], ["0-4294967295"]),
        "port_family": MoPropertyMeta("port_family", "portFamily", "string", VersionMeta.Version202m, MoPropertyMeta.READ_WRITE, 0x80, 0, 510, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version202m, MoPropertyMeta.READ_ONLY, 0x100, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version202m, MoPropertyMeta.READ_WRITE, 0x200, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version202m, MoPropertyMeta.READ_WRITE, 0x400, 0, 510, None, [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "isMultiPort": "is_multi_port", 
        "isPassthrough": "is_passthrough", 
        "isRetimerRequired": "is_retimer_required", 
        "numDcePorts": "num_dce_ports", 
        "portFamily": "port_family", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.is_multi_port = None
        self.is_passthrough = None
        self.is_retimer_required = None
        self.num_dce_ports = None
        self.port_family = None
        self.sacl = None
        self.status = None
        self.type = None

        ManagedObject.__init__(self, "AdaptorFamilyTypeDef", parent_mo_or_dn, **kwargs)



"""This module contains the general information for NwctrlDefinition ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class NwctrlDefinitionConsts:
    CDP_DISABLED = "disabled"
    CDP_ENABLED = "enabled"
    INT_ID_NONE = "none"
    LLDP_RECEIVE_DISABLED = "disabled"
    LLDP_RECEIVE_ENABLED = "enabled"
    LLDP_TRANSMIT_DISABLED = "disabled"
    LLDP_TRANSMIT_ENABLED = "enabled"
    MAC_REGISTER_MODE_ALL_HOST_VLANS = "all-host-vlans"
    MAC_REGISTER_MODE_ONLY_NATIVE_VLAN = "only-native-vlan"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    UPLINK_FAIL_ACTION_LINK_DOWN = "link-down"
    UPLINK_FAIL_ACTION_WARNING = "warning"


class NwctrlDefinition(ManagedObject):
    """This is NwctrlDefinition class."""

    consts = NwctrlDefinitionConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("NwctrlDefinition", "nwctrlDefinition", "nwctrl-[name]", VersionMeta.Version102d, "InputOutput", 0x1fff, [], ["admin", "ls-network", "ls-network-policy"], ['fabricEthEstcCloud', 'orgOrg', 'policySystemEp'], ['dpsecMac'], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "cdp": MoPropertyMeta("cdp", "cdp", "string", VersionMeta.Version102d, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["disabled", "enabled"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version102d, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version102d, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version102d, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version102d, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]),
        "lldp_init": MoPropertyMeta("lldp_init", "lldpInit", "byte", VersionMeta.Version411a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "lldp_receive": MoPropertyMeta("lldp_receive", "lldpReceive", "string", VersionMeta.Version224b, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["disabled", "enabled"], []),
        "lldp_transmit": MoPropertyMeta("lldp_transmit", "lldpTransmit", "string", VersionMeta.Version224b, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, ["disabled", "enabled"], []),
        "mac_register_mode": MoPropertyMeta("mac_register_mode", "macRegisterMode", "string", VersionMeta.Version201m, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, ["all-host-vlans", "only-native-vlan"], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version102d, MoPropertyMeta.NAMING, 0x100, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []),
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x200, None, None, None, ["local", "pending-policy", "policy"], []),
        "prop_acl": MoPropertyMeta("prop_acl", "propAcl", "ulong", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version102d, MoPropertyMeta.READ_ONLY, 0x400, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version102d, MoPropertyMeta.READ_WRITE, 0x800, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "uplink_fail_action": MoPropertyMeta("uplink_fail_action", "uplinkFailAction", "string", VersionMeta.Version102d, MoPropertyMeta.READ_WRITE, 0x1000, None, None, None, ["link-down", "warning"], []),
    }

    prop_map = {
        "cdp": "cdp", 
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "intId": "int_id", 
        "lldpInit": "lldp_init", 
        "lldpReceive": "lldp_receive", 
        "lldpTransmit": "lldp_transmit", 
        "macRegisterMode": "mac_register_mode", 
        "name": "name", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "propAcl": "prop_acl", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "uplinkFailAction": "uplink_fail_action", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.cdp = None
        self.child_action = None
        self.descr = None
        self.int_id = None
        self.lldp_init = None
        self.lldp_receive = None
        self.lldp_transmit = None
        self.mac_register_mode = None
        self.policy_level = None
        self.policy_owner = None
        self.prop_acl = None
        self.sacl = None
        self.status = None
        self.uplink_fail_action = None

        ManagedObject.__init__(self, "NwctrlDefinition", parent_mo_or_dn, **kwargs)



"""This module contains the meta information of ApeRemoveDevice ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ApeRemoveDevice", "apeRemoveDevice", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_serial": MethodPropertyMeta("InSerial", "inSerial", "Xs:string", "Version142b", "Input", False),
}

prop_map = {
    "cookie": "cookie",
    "inSerial": "in_serial",
}



# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from nose.tools import assert_equal
from ucsmsdk.ucsmeta import VersionMeta
from ucsmsdk.ucscoremeta import UcsVersion


def test_nightly_version1():
    version1 = UcsVersion("2.0(13aS6)")
    version2 = UcsVersion("3.0(1S10)")
    assert_equal((version1 < version2), True)


def test_nightly_version2():
    version1 = UcsVersion("2.0(13aS6)")
    version2 = UcsVersion("2.0(1S10)")
    assert_equal((version1 > version2), True)


def test_nightly_version3():
    # 2.0(2cS6) will be considered as 2.0(2d) internally
    version1 = UcsVersion("2.0(2cS6)")
    version2 = UcsVersion("2.0(2c)")
    assert_equal((version1 == version2), False)


def test_nightly_version4():
    version1 = UcsVersion("2.0(2cS6)")
    version2 = UcsVersion("2.0(3)")
    assert_equal((version1 < version2), True)


def test_spin_version1():
    # version interpreted as 4.0(2b)
    version1 = UcsVersion("4.0(2aS3)")
    version2 = UcsVersion("4.0(2b)")
    assert_equal((version1 == version2), True)


def test_spin_version2():
    # version interpreted as 4.0(234c)
    version1 = UcsVersion("4.0(234bS3)")
    version2 = UcsVersion("4.0(234c)")
    assert_equal((version1 == version2), True)


def test_spin_version3():
    # version interpreted as 4.0(2z)
    version1 = UcsVersion("4.0(2S3)")
    version2 = UcsVersion("4.0(2z)")
    assert_equal((version1 == version2), True)


def test_spin_version4():
    # version interpreted as 4.0(234z)
    version1 = UcsVersion("4.0(234S3)")
    version2 = UcsVersion("4.0(234z)")
    assert_equal((version1 == version2), True)


def test_patch_version1():
    # version interpreted as 4.0(235a)
    version1 = UcsVersion("4.0(234.5)")
    version2 = UcsVersion("4.0(235a)")
    assert_equal((version1 == version2), True)


def test_build_version1():
    # 4.2(0.175a) is an engineering build that will later become 4.2(1a)
    version1 = UcsVersion("4.2(0.175a)")
    version2 = UcsVersion("4.2(1a)")
    assert_equal((version1 < version2), True)


def test_build_version2():
    version1 = UcsVersion("4.2(0.175a)")
    version2 = UcsVersion("4.2(0.258a)")
    assert_equal((version1 < version2), True)


def test_spin_version5():
    # version interpreted as 4.2(2a)
    version1 = UcsVersion("4.2(1.2021052301)")
    version2 = UcsVersion("4.2(2a)")
    assert_equal((version1 == version2), True)


def test_spin_version6():
    # version interpreted as 4.2(1b)
    version1 = UcsVersion("4.2(1a.2021052301)")
    version2 = UcsVersion("4.2(1b)")
    assert_equal((version1 == version2), True)


def test_gt_same_major_version():
    version1 = VersionMeta.Version211a
    version2 = VersionMeta.Version211e
    assert_equal((version1 < version2), True)


def test_gt_different_major_version():
    version1 = VersionMeta.Version404a
    version2 = VersionMeta.Version412b
    assert_equal((version1 < version2), True)


def test_patch_versions():
    # when we don't see a patch version we use z
    # so 2.0(12) will be considered as 2.0(12z)
    version1 = UcsVersion("2.0(12b)")
    version2 = UcsVersion("2.0(12)")
    assert_equal((version1 > version2), False)



"""This module contains the general information for StorageEnclosureCap ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class StorageEnclosureCapConsts:
    REMOVABLE_FALSE = "false"
    REMOVABLE_NO = "no"
    REMOVABLE_TRUE = "true"
    REMOVABLE_YES = "yes"
    TYPE_DEDICATED_REAR_SSD_ENCLOSURE = "dedicated-rear-ssd-enclosure"
    TYPE_HDD_EXPANSION_TRAY = "hdd-expansion-tray"
    TYPE_HDD_MOTHER_BOARD = "hdd-mother-board"
    TYPE_IOE_NVME_ENCLOSURE = "ioe-nvme-enclosure"
    TYPE_SB_NVME_ENCLOSURE = "sb-nvme-enclosure"
    TYPE_SERVER_FRONT_LOAD = "server-front-load"
    TYPE_SERVER_MID = "server-mid"
    TYPE_SERVER_NVME = "server-nvme"
    TYPE_SERVER_PCH = "server-pch"
    TYPE_SERVER_REAR = "server-rear"
    TYPE_SIOC_NVME_ENCLOSURE = "sioc-nvme-enclosure"
    TYPE_UNKNOWN = "unknown"


class StorageEnclosureCap(ManagedObject):
    """This is StorageEnclosureCap class."""

    consts = StorageEnclosureCapConsts()
    naming_props = set(['type'])

    mo_meta = MoMeta("StorageEnclosureCap", "storageEnclosureCap", "physical-holder-[type]", VersionMeta.Version312b, "InputOutput", 0x3f, [], [""], ['equipmentBladeCapProvider', 'equipmentChassisCapProvider', 'equipmentRackUnitCapProvider'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version312b, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "disk_base_id": MoPropertyMeta("disk_base_id", "diskBaseId", "uint", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "disk_variant": MoPropertyMeta("disk_variant", "diskVariant", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "num_slots": MoPropertyMeta("num_slots", "numSlots", "ushort", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "removable": MoPropertyMeta("removable", "removable", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version312b, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version312b, MoPropertyMeta.NAMING, 0x20, None, None, None, ["dedicated-rear-ssd-enclosure", "hdd-expansion-tray", "hdd-mother-board", "ioe-nvme-enclosure", "sb-nvme-enclosure", "server-front-load", "server-mid", "server-nvme", "server-pch", "server-rear", "sioc-nvme-enclosure", "unknown"], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "diskBaseId": "disk_base_id", 
        "diskVariant": "disk_variant", 
        "dn": "dn", 
        "id": "id", 
        "numSlots": "num_slots", 
        "removable": "removable", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, type, **kwargs):
        self._dirty_mask = 0
        self.type = type
        self.child_action = None
        self.descr = None
        self.disk_base_id = None
        self.disk_variant = None
        self.id = None
        self.num_slots = None
        self.removable = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "StorageEnclosureCap", parent_mo_or_dn, **kwargs)
